--Sendmenu by Megiddo
--VERSION 1.1
--
--Changelog:
--v1.1 5/22/06
-- * Fixed overflow problems ( Timer delays menus, you can change the delay with the increment variable )
--
--v1 02/22/06
-- * ulx_sv_sendmenuclearold now defaults to off
-- * Fixed cvar checks
-- * Added ulx_sv_sendmenudir
-- * Added some ULX checks
--
--v0.9 02/16/06
-- * Initial release
--
-- Thanks to:
-- TheDarkFactor for helping me track and kill the overflow problem as efficiently as possible.

assert( ULX_VERSION, "You must have ULX to run the sendmenu script!" )
assert( ULX_VERSION >= 1.1, "You must be running ULX version 1.1 or higher to use the sendmenu script!" )

if ULX_VERSION < 1.11 then
	_Msg( "[ULX SENDMENU] Warning: The sendmenu script will function with ULX v1.1, but I strongly recommend an upgrade to v1.11 or better" )
end

ULX_CONVAR( "ulx_sv_sendmenuenabled", "1", ACCESS_BAN, "- If enabled, clients will be sent the menus from the server" )
ULX_CONVAR( "ulx_sv_sendmenuclearold", "0", ACCESS_BAN, "- If enabled with sendmenuenabled, the client's original menu will be cleared" )
ULX_CONVAR( "ulx_sv_sendmenudir", "settings/menu_props", ACCESS_RCON, "- Where sendmenu will take it's menus from, USE '/' AND LEAVE OFF THE TRAILING '/'" )

gMenus = {}

do -- Contain our local variables to this scope
	local files = getFilesFromDir( ulx_sv_sendmenudir )
	for i=1, table.getn( files ) do
		local file = readFile( ulx_sv_sendmenudir .. "/" .. files[ i ], "//" )
		local title = stripQuotes( file[ 1 ] ) -- The first line *should* have the title, please note this method fails if there's multiple menus in one file
		gMenus[ title ] = {}
		for l=3, table.getn( file ) - 1 do -- Skip to the third line to get to the meta of the file
			local first = string.gsub( file[ l ], "^[ \t]*\"(.-)\"[ \t]*\"(.-)\".*$", "%1" )
			local second = string.gsub( file[ l ], "^[ \t]*\"(.-)\"[ \t]*\"(.-)\".*$", "%2" )
			table.insert( gMenus[ title ], { k=first, v=second } )
		end		
	end
end

function sendMenus( userid )
	if ulx_sv_sendmenuenabled == "0" then
		return
	end
	
	if ulx_sv_sendmenuclearold ~= "0" then
		_spawnmenu.RemoveAll( userid )
	end
	
	local delay = 0
	local increment = 0.05
	
	for title in pairs( gMenus ) do
		AddTimer( delay, 1, sendMenu, userid, title )
		delay = delay + increment
	end
end

function sendMenu( userid, title )
	for i=1, table.getn( gMenus[ title ] ) do
		_spawnmenu.AddItem( userid, title, gMenus[ title ][ i ].k, gMenus[ title ][ i ].v )
	end	
end

HookEvent( "eventPlayerInitialSpawn", sendMenus )
